@@ -246,16 +246,13 @@ display_about_dialog ()
         GdkPixbuf *pixbuf = NULL;
 
         const gchar *authors[] = {
-                N_("Author and maintainer: Dodji Seketeli <dodji@gnome.org>"),
-                "\n\n",
+                N_("Author and maintainer:"),
+		"Dodji Seketeli <dodji@gnome.org>\n",
                 N_("Substantial contributors:"),
-                "\n",
-                N_("Nicolas Centa <happypeng@free.fr>"),
-                N_("Philippe Mechai <pmechai@free.fr>"),
-                N_("Baptiste Mille-Mathias <bmm80@free.fr>"),
-                "\n\n",
+                "Nicolas Centa <happypeng@free.fr>",
+                "Philippe Mechai <pmechai@free.fr>",
+                "Baptiste Mille-Mathias <bmm80@free.fr>\n",
                 N_("Former contributors:"),
-                "\n",
                 "Gael Chamoulaud<strider@gnome.org>", 
                 "Stephane Bonhomme<s.bonhomme@wanadoo.fr>",
                 NULL
