@@ -475,11 +475,9 @@ build_name_edition_dialog (MlViewAppContext * a_app_context)
         result = gtk_dialog_new_with_buttons
                  (_("Type the name of the current view"), NULL,
                   GTK_DIALOG_MODAL, 
-                  GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT, 
+                  GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL, 
                   GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,                  
                   NULL);
-        gtk_dialog_set_default_response (GTK_DIALOG (result),
-                                         GTK_RESPONSE_ACCEPT) ;
 
         name_entry_field = gtk_entry_new ();
 
@@ -490,6 +488,11 @@ build_name_edition_dialog (MlViewAppContext * a_app_context)
                                      (GTK_DIALOG (result)->vbox),
                                      name_entry_field) ;
 
+	gtk_entry_set_activates_default (GTK_ENTRY (name_entry_field),
+			                 TRUE) ;
+       
+	gtk_dialog_set_default_response (GTK_DIALOG (result),
+                                         GTK_RESPONSE_ACCEPT) ;
         gtk_widget_show_all (result);
 
         return result;
@@ -519,6 +522,10 @@ set_name_edition_widget_value (GtkWidget * a_edition_widget,
                 gtk_entry_set_text (name_entry, a_value);
         else
                 gtk_entry_set_text (name_entry, "");
+
+	gtk_dialog_set_default_response (GTK_DIALOG (a_edition_widget),
+                                         GTK_RESPONSE_ACCEPT) ;
+        
 }
 
 
